@@ -93,6 +93,7 @@ def _custom_json_formatter(record: dict):
     return '{custom_json}\n'
 
 
+
 def _init():
     ## Loading environment variables from .env file, if it's exits:
     _env_filename = '.env'
@@ -170,19 +171,22 @@ def _init():
                 backtrace=_configs_dict['use_backtrace'],
                 diagnose=_configs_dict['use_diagnose'])
 
-    _APP_NAME = str(os.getenv('APP_NAME')).strip().replace(' ', '_').lower()
-    if _APP_NAME == 'none':
+    ## Checking log file handlers enabled or not:
+    if _configs_dict['use_log_file'] or _configs_dict['use_log_json']:
+        ## Setting 'APP_NAME':
         _APP_NAME = os.path.splitext(os.path.basename(sys.argv[0]))[0]
-        logger.debug(f"Not found 'APP_NAME' environment variable, changed to '{_APP_NAME}'.")
+        if os.getenv('APP_NAME') and os.getenv('APP_NAME').strip():
+            _APP_NAME = os.getenv('APP_NAME').strip().replace(' ', '_').lower()
+        else:
+            logger.debug(f"Not found 'APP_NAME' environment variable, changed app name to '{_APP_NAME}'.")
 
-    _ENABLE_LOG_FILE = (os.getenv('ENABLE_LOG_FILE', 'true').strip().lower() == 'true')
-    _ENABLE_LOG_JSON = (os.getenv('ENABLE_LOG_JSON', 'false').strip().lower() == 'true')
-    if _ENABLE_LOG_FILE or _ENABLE_LOG_JSON:
+        ## Checking and creating 'logs_dir':
+        _LOGS_DIR = os.path.join(_current_dir, 'logs')
+        if ('logs_dir' in _configs_dict) and _configs_dict['logs_dir'].strip():
+            _LOGS_DIR = _configs_dict['logs_dir'].strip()
 
-        _LOGS_DIR = str(os.getenv('LOGS_DIR')).strip()
-        if _LOGS_DIR == 'None':
-            _LOGS_DIR = os.path.join(_current_dir, 'logs')
-            logger.debug(f"Not found 'LOGS_DIR' environment variable, changed to '{_LOGS_DIR}'.")
+        if os.getenv('LOGS_DIR') and os.getenv('LOGS_DIR').strip():
+            _LOGS_DIR = os.getenv('LOGS_DIR').strip()
 
         if not os.path.isdir(_LOGS_DIR):
             logger.warning(f"'{_LOGS_DIR}' directory doesn't exist!")
@@ -196,6 +200,7 @@ def _init():
                     exit(2)
             logger.success(f"Successfully created '{_LOGS_DIR}' directory!")
 
+        ## Setting up log file handlers:
         _rotate_when = datetime.time(_configs_dict['rotate_when']['at_hour'], _configs_dict['rotate_when']['at_minute'], _configs_dict['rotate_when']['at_second'])
         if _configs_dict['use_log_file']:
             ## Initializing log file handler:
